@@ -9,6 +9,7 @@ global_config = get_driver().config
 config = Config(**global_config.dict())
 
 from .data_source import get_av_data
+import re
 # Export something for other plugin
 # export = nonebot.export()
 # export.foo = "bar"
@@ -16,8 +17,11 @@ from .data_source import get_av_data
 # @export.xxx
 # def some_function():
 #     pass
-biliav = on_regex("^av*|^BV*")
+biliav = on_regex("av(\d{1,12})|BV(1[A-Za-z0-9]{2}4.1.7[A-Za-z0-9]{2})")
 @biliav.handle()
 async def handle(bot:Bot,event:Event,state:T_State):
-    rj = await get_av_data(event.get_message())
+    avcode = re.search('av(\d{1,12})|BV(1[A-Za-z0-9]{2}4.1.7[A-Za-z0-9]{2})', str(event.get_message()))
+    if avcode==None:
+        return
+    rj = await get_av_data(avcode[0])
     await biliav.send(rj)
